==> nextcloud-26.0.10.tgz: nextcloud/apps/updatenotification/l10n/eo.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} disponeblas. Ekhavi pli da informo pri kiel ĝisdatigi.",
    "Channel updated" : "Kanalo ĝisdatigita",
    "Update notifications" : "Sciigoj pri ĝisdatigoj",
    "The update server could not be reached since %d days to check for new updates." : "La servilo de ĝisdatigoj ne atingeblis de %d tagoj.",
    "Please check the Nextcloud and server log files for errors." : "Bv. kontroli la protokoldosieron de Nextcloud kaj de la servilo pri eraroj.",
    "Update to %1$s is available." : "Ĝisdatigo al %1$s disponeblas.",
    "Update for {app} to version %s is available." : "Ĝisdatigo de {app} al versio %s disponeblas.",
    "Update notification" : "Sciigo pri ĝisdatigoj",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Montras sciigojn pri ĝisdatigoj pri Nextcloud kaj provizas ununuran ensaluton („SSO“ angle) por la ĝisdatigilo.",
    "Update" : "Ĝisdatigi",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versio, kiun vi nun uzas, ne plus estas subtenata. Bv. ĝisdatigi al subtenata versio kiel eble plej rapide.",
    "View in store" : "Vidi en la aplikaĵejo",
    "Open updater" : "Malfermi la ĝisdatigilon",
    "Download now" : "Elŝuti nun",
    "What's new?" : "Kio nova?",
    "View changelog" : "Vidi ŝanĝoprotokolon",
    "The update check is not yet finished. Please refresh the page." : "La kontrolo pri ĝisdatigoj ankoraŭ ne finiĝis. Bv. aktualigi la paĝon.",
    "Your version is up to date." : "Via versio estas ĝisdata.",
    "A non-default update server is in use to be checked for updates:" : "Nedefaŭlta servilo por ĝisdatigoj uziĝas por kontroli ĝisdatigojn:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vi povas ĝisdatigi iam ajn al pli nova versio. Sed vi povas neniam malĝisdatigi al pli stabila versio.",
    "Notify members of the following groups about available updates:" : "Sciigi anojn de la jenaj grupoj pri disponeblaj ĝisdatigoj:",
    "The selected update channel makes dedicated notifications for the server obsolete." : "La elektita kanalo pri ĝisdatigoj igas la dediĉitajn sciigojn por la servilo neutilaj.",
    "The selected update channel does not support updates of the server." : "La elektita ĝisdatiga kanalo ne subtenas ĝisdatigojn de la servilo.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Nova versio disponeblas: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Kontrolita je {lastCheckedDate}",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bv. certigi, ke via dosiero „config.php“ ne agordas <samp>appstoreenabled</samp> al malvero („false“).",
    "Enterprise" : "Firmao",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Por firmaa uzo. Ĝi uzas ĉiam la plej freŝan flikaĵon, sed ĝi ne tuj ĝisdatiĝos al la sekva ĉefversio. Transiro al la sekva ĉefversio okazos, kiam  Nextcloud GmbH faros plifortigaĵojn kaj pliajn testojn rilate al uzo en granda kaj grava kunteksto. Ĝi nur disponeblas por klientoj kaj ĝi estas la Nextcloud-a firmapakaĵo.",
    "Stable" : "Stabila",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La plej freŝa stabila versio. Ĝi taŭgas por ĉiutaga uzo, kaj ĝi ĝisdatiĝos ĉiufoje al la lasta ĉefversio.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Antaŭeldona versio nur por testi novajn trajtojn; ne taŭgas por produktada medio.",
    "Update channel:" : "Ĝisdatiga kanalo:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.11.tgz: nextcloud/apps/updatenotification/l10n/eo.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} disponeblas. Ekhavi pli da informo pri kiel ĝisdatigi.",
    "Channel updated" : "Kanalo ĝisdatigita",
    "Update notifications" : "Sciigoj pri ĝisdatigoj",
    "The update server could not be reached since %d days to check for new updates." : "La servilo de ĝisdatigoj ne atingeblis de %d tagoj.",
    "Please check the Nextcloud and server log files for errors." : "Bv. kontroli la protokoldosieron de Nextcloud kaj de la servilo pri eraroj.",
    "Update for {app} to version %s is available." : "Ĝisdatigo de {app} al versio %s disponeblas.",
    "Update notification" : "Sciigo pri ĝisdatigoj",
    "Update" : "Ĝisdatigi",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La versio, kiun vi nun uzas, ne plus estas subtenata. Bv. ĝisdatigi al subtenata versio kiel eble plej rapide.",
    "View in store" : "Vidi en la aplikaĵejo",
    "Open updater" : "Malfermi la ĝisdatigilon",
    "Download now" : "Elŝuti nun",
    "What's new?" : "Kio nova?",
    "View changelog" : "Vidi ŝanĝoprotokolon",
    "The update check is not yet finished. Please refresh the page." : "La kontrolo pri ĝisdatigoj ankoraŭ ne finiĝis. Bv. aktualigi la paĝon.",
    "Your version is up to date." : "Via versio estas ĝisdata.",
    "A non-default update server is in use to be checked for updates:" : "Nedefaŭlta servilo por ĝisdatigoj uziĝas por kontroli ĝisdatigojn:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vi povas ĝisdatigi iam ajn al pli nova versio. Sed vi povas neniam malĝisdatigi al pli stabila versio.",
    "Notify members of the following groups about available updates:" : "Sciigi anojn de la jenaj grupoj pri disponeblaj ĝisdatigoj:",
    "The selected update channel makes dedicated notifications for the server obsolete." : "La elektita kanalo pri ĝisdatigoj igas la dediĉitajn sciigojn por la servilo neutilaj.",
    "The selected update channel does not support updates of the server." : "La elektita ĝisdatiga kanalo ne subtenas ĝisdatigojn de la servilo.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Nova versio disponeblas: <strong>{newVersionString}</strong>",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Bv. certigi, ke via dosiero „config.php“ ne agordas <samp>appstoreenabled</samp> al malvero („false“).",
    "Enterprise" : "Firmao",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Por firmaa uzo. Ĝi uzas ĉiam la plej freŝan flikaĵon, sed ĝi ne tuj ĝisdatiĝos al la sekva ĉefversio. Transiro al la sekva ĉefversio okazos, kiam  Nextcloud GmbH faros plifortigaĵojn kaj pliajn testojn rilate al uzo en granda kaj grava kunteksto. Ĝi nur disponeblas por klientoj kaj ĝi estas la Nextcloud-a firmapakaĵo.",
    "Stable" : "Stabila",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La plej freŝa stabila versio. Ĝi taŭgas por ĉiutaga uzo, kaj ĝi ĝisdatiĝos ĉiufoje al la lasta ĉefversio.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Antaŭeldona versio nur por testi novajn trajtojn; ne taŭgas por produktada medio.",
    "Update to %1$s is available." : "Ĝisdatigo al %1$s disponeblas.",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Montras sciigojn pri ĝisdatigoj pri Nextcloud kaj provizas ununuran ensaluton („SSO“ angle) por la ĝisdatigilo.",
    "Update channel:" : "Ĝisdatiga kanalo:",
    "Checked on {lastCheckedDate}" : "Kontrolita je {lastCheckedDate}"
},
"nplurals=2; plural=(n != 1);");
